function dispgrap(hand,par)
%quick re-drawing of current graphs on closed loop window
%inputs:
%hand ... 	handler for axes on which we want to draw
%par ... 	type of graph to draw: 1=|Sup|, 2=|Syp|, 3=|Syb|, 4=pole-zero map of CL, 
%				5=pole-zero map of controller, 6=step response for disturbance

global colorset;
global A B Ts;
global Ts;
global R S Hr Hs;
global Sypf_num Sypf_den Supf_num Supf_den; %numerators and denominators of 2poles/2zeros filters for Syp and Sup 
global Sypf Supf; %flags for the filters

global Wsypu Wsypd Wsup Wsyb fn;

global h0;
global xscal yscal Nf_points F_lin_log;

if(isempty(A)|isempty(B)|isempty(R)|isempty(S)) return; end;

if(par<4)%compute and disp sens fn
   if Supf, Rr=conv(R,conv(Hr,Supf_num));else Rr=conv(R,Hr);end;
   if Sypf, Sr=conv(S,conv(Hs,Sypf_num));else Sr=conv(S,Hs);end;
   if(par==1)%Sup
      Snum=conv(Rr,A);
   elseif(par==2)%Syp
      Snum=conv(Sr,A);
   elseif(par==3)%Syb
      Snum=conv(Rr,B);
   end;
	Sden=addvec(conv(A,Sr),conv(B,Rr));
   
   if F_lin_log==1,
      fnall=linspace(0,0.5,Nf_points);%[linspace(1e-8,1e-3,200) linspace(2e-3,0.499,499)];
      set(hand,'Xscale','linear');
   elseif F_lin_log==2,
      fnall=logspace(1e-4,0.5,Nf_points);
      set(hand,'Xscale','log');      
   end;
   
	fall=fnall/Ts;
   
   
   [Sfn,frq]=freqz(Snum,Sden,fall,1/Ts);
   Sfn=abs(Sfn);
   frq=frq*(Ts);%f/fs
   if (yscal==1)%log scales
      for K=1:length(Sfn) if(Sfn(K)==0) Sfn(K)=-PRECISION*10; end;end;%remove pure zeros
      Sfn=20*log10(abs(Sfn));%sens. function
   end;
   prxscal=0;
  	if(strcmp(get(get(hand,'XLabel'),'String'),'Frequency [Hz]')) prxscal=1;
   elseif(strcmp(get(get(hand,'XLabel'),'String'),'Frequency [rad/s]')) prxscal=2;
   elseif(strcmp(get(get(hand,'XLabel'),'String'),'Relative Frequency f/fs')) prxscal=3;
   end;
   pryscal=0;
   if(strcmp(get(get(hand,'YLabel'),'String'),'Magnitude [lin]')) pryscal=2;else pryscal=1;end 
   
   x=get(hand,'UserData');
   if(isempty(x)) x=-1;end;
   if( (x(1)==par)&(pryscal==yscal)&(prxscal==xscal)&(length(Sfn)==length(get(x(2),'YData')) ))
      %only fn. change
      set(x(2),'YData',Sfn);
   else
      %change all
      yli=[];
      if(x(1)~=-1) %remove previous graph
         for K=2:length(x) delete(x(K));end;
      end;
      %set xdata
      if(xscal==1) xdt=frq/Ts;xdtt=fn/Ts;
      elseif(xscal==2) xdt=(frq*2*pi)/Ts;xdtt=(fn*2*pi)/Ts;
      elseif(xscal==3) xdt=frq;xdtt=fn;
      end;
      axes(hand);%set current axes
      cla;
      %tempates
      if(par==1)%sup
	      if(yscal==2)%linear scale
            Wsup1=10.^(Wsup/20);
         else%log scale
            Wsup1=Wsup;
         end;
		   ht=line('Color',getfield(colorset,'Template'), ...
			'LineStyle','-', ...
			'LineWidth',[2], ...
			'Marker','none', ...
			'XData',xdtt, ...
			'YData',Wsup1,...
         'Parent',[hand]);
			yli=[min(Wsup1),max(Wsup1)];
	   elseif(par==2)%syp
      	index=1;   
		   while(imag(Wsypd(index))~=0) index=index+1;end;
         for K=index:length(fn) f2(K-index+1)=fn(K);Wsypd2(K-index+1)=Wsypd(K);end;
			%set xdata2 for lower template         
	      if(xscal==1) xdt2=f2/Ts;
	      elseif(xscal==2) xdt2=(f2*2*pi)/Ts;
	      elseif(xscal==3) xdt2=f2;
	      end;
            
	      if(yscal==2)%linear scale
            Wsypu1=10.^(Wsypu/20);
            Wsypd1=10.^(Wsypd2/20);
         else%log scale
            Wsypu1=Wsypu;
            Wsypd1=Wsypd2;
	      end;
		   ht(1)=line('Color',getfield(colorset,'Template'), ...
			'LineStyle','-', ...
			'LineWidth',[2], ...
			'Marker','none', ...
			'XData',xdt2, ...
			'YData',Wsypd1,...
         'Parent',[hand]);
		   ht(2)=line('Color',getfield(colorset,'Template'), ...
			'LineStyle','-', ...
			'LineWidth',[2], ...
			'Marker','none', ...
			'XData',xdtt, ...
			'YData',Wsypu1,...
         'Parent',[hand]);
			yli=[min(Wsypd1),max(Wsypu1)];
	   elseif(par==3) %Syb
	      if(yscal==2)%linear scale
            Wsyb1=10.^(Wsyb/20);
         else%log scale
            Wsyb1=Wsyb;
	      end;
		   ht=line('Color',getfield(colorset,'Template'), ...
			'LineStyle','-', ...
			'LineWidth',[2], ...
			'Marker','none', ...
			'XData',xdtt, ...
			'YData',Wsyb1,...
         'Parent',[hand]);
			yli=[min(Wsyb1),max(Wsyb1)];
		end;%end templates   		   
      %sens function
	   hs=line('Color',getfield(colorset,'Current'), ...
			'LineStyle','-', ...
			'LineWidth',[0.5], ...
			'Marker','none', ...
			'XData',xdt, ...
			'YData',Sfn,...
         'Parent',[hand]);
	   if(min(Sfn)<yli(1)) yli(1)=min(Sfn);end;	
      if(max(Sfn)>yli(2)) yli(2)=max(Sfn);end;   
   	set(hand,'UserData',[par hs ht]);
	   if(xscal==1) set(get(hand,'XLabel'),'String','Frequency [Hz]');
		elseif(xscal==2) set(get(hand,'XLabel'),'String','Frequency [rad/s]');
      elseif(xscal==3) set(get(hand,'XLabel'),'String','Relative Frequency f/fs');
      end;
      if (yscal==1) set(get(hand,'YLabel'),'String','Magnitude [dB]');
      else set(get(hand,'YLabel'),'String','Magnitude [lin]');end;
      set(get(hand,'XLabel'),'FontSize',8);
      set(get(hand,'YLabel'),'FontSize',8);
      
      yli(1)=yli(1)+0.07*(yli(2)-yli(1))*sign(yli(1));
      yli(2)=yli(2)+0.07*(yli(2)-yli(1))*sign(yli(2));
      set(hand,'Xlim',[min(xdt),max(xdt)],'Ylim',yli);
      ylim(hand,'auto');
      set(hand,'XGrid','on','YGrid','on');
		disphld(hand,par);%display held graphs
   end;
elseif(par==4)|(par==5)%pole-zero map CL or Controller
   if Supf, Rr=conv(R,conv(Hr,Supf_num));else Rr=conv(R,Hr);end;
   if Sypf, Sr=conv(S,conv(Hs,Sypf_num));else Sr=conv(S,Hs);end;
   den=addvec(conv(A,Sr),conv(B,Rr));
   if par==4, %Closed loop
	   zero=roots(B);
      pole=roots(den);
   elseif(par==5),%Controller
  	   zero=roots(Rr);
      pole=roots(Sr);
	end;
   x=get(hand,'UserData');
   if(isempty(x)) x=0;end;
   if(x(1)==par)
      %only fn. change
      set(x(2),'YData',imag(pole));
      set(x(2),'XData',real(pole));
      if(isempty(zero)~=1)
	      set(x(3),'YData',imag(zero));
         set(x(3),'XData',real(zero));
      end;
   else
      %change all
      if(x(1)~=0) %remove previous graph
         for K=2:length(x) delete(x(K));end;
      end;
      %unit circle     
      axes(hand);%set current axes
      cla;
      zgrid;
      ch=get(hand,'Children');
      ht=[];
      for K=1:length(ch) if(strcmp(get(ch(K),'Type'),'line')) ht=[ht ch(K)];end;K=K+1;end;%take handler to grid
      %poles
      hs=[];
      hs(1)=plot(real(pole),imag(pole),'rx');
      set(hs(1),'Markersize',10);
      if(isempty(zero)~=1)
         hs(2)=plot(real(zero),imag(zero),'bo');
         set(hs(2),'Markersize',10);
      end;
      set(hand,'UserData',[par hs ht]);
      set(get(hand,'XLabel'),'String','Real');
      set(get(hand,'YLabel'),'String','Imag');
      set(hand,'XGrid','on','YGrid','on');
      set(hand,'Fontsize',8);
      xl=get(hand,'Xlim');
      yl=get(hand,'Ylim');
      if(xl(1)>-1) xl(1)=-1;end;
      if(xl(2)<1) xl(2)=1;end;
      if(yl(1)>-1) yl(1)=-1;end;
      if(yl(2)<1) yl(2)=1;end;
      set(hand,'Xlim',xl);
      set(hand,'Ylim',yl);
		disphld(hand,par);%display held graphs
   end;
   
elseif(par==6)%step response for disturbance
	[r,s,pax,hsapp,hrapp]=rs_complete;   
   Sden=addvec(conv(A,s),conv(B,r));
   Snum=conv(A,s);
   sys=tf(Snum,Sden,Ts);
   tmax=40/(2*pi*0.05/Ts);
   [resp,tim]=step(sys,tmax);
   x=get(hand,'UserData');
   if(isempty(x)) x=0;end;
   if(x(1)==par)
      %only fn. change
      set(x(2),'YData',resp);      
   else
      %change everything
      if(x(1)~=-1) %remove previous graph
         for K=2:length(x) delete(x(K));end;
      end;
      axes(hand);
      cla;
      hs=plot(tim,resp,'r-');
      yli=[min(resp)+0.07*(max(resp)-min(resp))*sign(min(resp)),max(resp)+0.07*(max(resp)-min(resp))*sign(max(resp))];
      set(hand,'Ylim',yli,'Xlim',[min(tim),max(tim)]);
      set(hs,'Color',getfield(colorset,'Current'));
      set(hand,'UserData',[par hs]);
      set(get(hand,'XLabel'),'String','Time [sec]');
      set(get(hand,'YLabel'),'String','Magnitude');
      ylim(hand,'auto');      
      set(hand,'XGrid','on','YGrid','on');
      set(hand,'Fontsize',8);
		disphld(hand,par);%display held graphs
   end;      
   

end;

